Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Registrar ¶
type Registrar func(*Router) []routeDef
Registrar returns a cohesive group of admin routes, such as auth, documents, management, or debug.
type Router ¶
type Router struct {
// contains filtered or unexported fields
}
Router owns the authenticated admin HTTP surface and the theme-backed admin shell.
func (*Router) RegisterRegistrar ¶
RegisterRegistrar appends an admin route group to the router.
func (*Router) RegisterRoutes ¶
RegisterRoutes mounts the admin shell, admin theme assets, plugin extension assets, and all registered admin route groups.
Click to show internal directories.
Click to hide internal directories.